aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorPeter Zhu <peter@peterzhu.ca>2023-07-13 09:42:24 -0400
committerPeter Zhu <peter@peterzhu.ca>2023-07-13 14:48:14 -0400
commitde327ccb63db9f929949a499476647f8def84be2 (patch)
tree57876af86d0c506b1f09d1ab46a0e03f88f727b0 /include
parent5ebc13311607a7af5423337d64b406c62b221bf9 (diff)
downloadruby-de327ccb63db9f929949a499476647f8def84be2.tar.gz
Remove RARRAY_PTR_USE_TRANSIENT
RARRAY_PTR_USE now does the same things as RARRAY_PTR_USE_TRANSIENT.
Diffstat (limited to 'include')
-rw-r--r--include/ruby/internal/core/rarray.h14
1 files changed, 2 insertions, 12 deletions
diff --git a/include/ruby/internal/core/rarray.h b/include/ruby/internal/core/rarray.h
index 1815349d77..c415a0acd6 100644
--- a/include/ruby/internal/core/rarray.h
+++ b/include/ruby/internal/core/rarray.h
@@ -369,18 +369,8 @@ rb_array_const_ptr(VALUE a)
RBIMPL_RARRAY_STMT(ary, ptr_name, expr)
/**
- * Identical to #RARRAY_PTR_USE, except the pointer can be a transient one.
- *
- * @param ary An object of ::RArray.
- * @param ptr_name A variable name which points the C array in `expr`.
- * @param expr The expression that touches `ptr_name`.
- */
-#define RARRAY_PTR_USE_TRANSIENT(ary, ptr_name, expr) \
- RBIMPL_RARRAY_STMT(ary, ptr_name, expr)
-
-/**
* Wild use of a C pointer. This function accesses the backend storage
* directly. This is slower than #RARRAY_PTR_USE_TRANSIENT. It exercises
* extra manoeuvres to protect our generational GC. Use of this function is
* considered archaic. Use a modern way instead.
*
@@ -415,7 +405,7 @@ RARRAY_PTR(VALUE ary)
static inline void
RARRAY_ASET(VALUE ary, long i, VALUE v)
{
- RARRAY_PTR_USE_TRANSIENT(ary, ptr,
+ RARRAY_PTR_USE(ary, ptr,
RB_OBJ_WRITE(ary, &ptr[i], v));
}
@@ -369,18 +369,8 @@ rb_array_const_ptr(VALUE a)
* Wild use of a C pointer. This function accesses the backend storage
- * directly. This is slower than #RARRAY_PTR_USE_TRANSIENT. It exercises
+ * directly. This is slower than #RARRAY_PTR_USE. It exercises
* extra manoeuvres to protect our generational GC. Use of this function is
* considered archaic. Use a modern way instead.